@@ -86,42 +86,42 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_events
-import aws_cdk.aws_lambda
-import aws_cdk.aws_s3
-import aws_cdk.aws_sns
-import aws_cdk.core
+import aws_cdk.aws_events as _aws_cdk_aws_events_efcdfa54
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_55f001a5
+import aws_cdk.aws_sns as _aws_cdk_aws_sns_889c7272
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
 class Certbot(
-    aws_cdk.core.Construct,
+    _aws_cdk_core_f4b25747.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@renovosolutions/cdk-library-certbot.Certbot",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
         hosted_zone_names: typing.Sequence[builtins.str],
         letsencrypt_domains: builtins.str,
         letsencrypt_email: builtins.str,
-        bucket: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        bucket: typing.Optional[_aws_cdk_aws_s3_55f001a5.Bucket] = None,
         enable_insights: typing.Optional[builtins.bool] = None,
         enable_object_deletion: typing.Optional[builtins.bool] = None,
         function_description: typing.Optional[builtins.str] = None,
         function_name: typing.Optional[builtins.str] = None,
         insights_arn: typing.Optional[builtins.str] = None,
-        layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
+        layers: typing.Optional[typing.Sequence[_aws_cdk_aws_lambda_5443dbc3.ILayerVersion]] = None,
         object_prefix: typing.Optional[builtins.str] = None,
         preferred_chain: typing.Optional[builtins.str] = None,
         re_issue_days: typing.Optional[jsii.Number] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[_aws_cdk_core_f4b25747.RemovalPolicy] = None,
         run_on_deploy: typing.Optional[builtins.bool] = None,
         run_on_deploy_wait_minutes: typing.Optional[jsii.Number] = None,
-        schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
-        sns_topic: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        schedule: typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule] = None,
+        sns_topic: typing.Optional[_aws_cdk_aws_sns_889c7272.Topic] = None,
+        timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
     ) -> None:
         '''
         :param scope: -
@@ -147,7 +147,7 @@ class Certbot(
         :param timeout: The timeout duration for Lambda function. Default: cdk.Duraction.seconds(180)
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Certbot.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0a97c57094adcc5a6d82e25accd2d32cc4403f75edfb6bdf2875a72fc23b1f8b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CertbotProps(
@@ -176,8 +176,8 @@ class Certbot(
 
     @builtins.property
     @jsii.member(jsii_name="handler")
-    def handler(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "handler"))
+    def handler(self) -> _aws_cdk_aws_lambda_5443dbc3.Function:
+        return typing.cast(_aws_cdk_aws_lambda_5443dbc3.Function, jsii.get(self, "handler"))
 
 
 @jsii.data_type(
@@ -212,22 +212,22 @@ class CertbotProps:
         hosted_zone_names: typing.Sequence[builtins.str],
         letsencrypt_domains: builtins.str,
         letsencrypt_email: builtins.str,
-        bucket: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        bucket: typing.Optional[_aws_cdk_aws_s3_55f001a5.Bucket] = None,
         enable_insights: typing.Optional[builtins.bool] = None,
         enable_object_deletion: typing.Optional[builtins.bool] = None,
         function_description: typing.Optional[builtins.str] = None,
         function_name: typing.Optional[builtins.str] = None,
         insights_arn: typing.Optional[builtins.str] = None,
-        layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
+        layers: typing.Optional[typing.Sequence[_aws_cdk_aws_lambda_5443dbc3.ILayerVersion]] = None,
         object_prefix: typing.Optional[builtins.str] = None,
         preferred_chain: typing.Optional[builtins.str] = None,
         re_issue_days: typing.Optional[jsii.Number] = None,
-        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
+        removal_policy: typing.Optional[_aws_cdk_core_f4b25747.RemovalPolicy] = None,
         run_on_deploy: typing.Optional[builtins.bool] = None,
         run_on_deploy_wait_minutes: typing.Optional[jsii.Number] = None,
-        schedule: typing.Optional[aws_cdk.aws_events.Schedule] = None,
-        sns_topic: typing.Optional[aws_cdk.aws_sns.Topic] = None,
-        timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        schedule: typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule] = None,
+        sns_topic: typing.Optional[_aws_cdk_aws_sns_889c7272.Topic] = None,
+        timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
     ) -> None:
         '''
         :param hosted_zone_names: Hosted zone names that will be required for DNS verification with certbot.
@@ -251,7 +251,7 @@ class CertbotProps:
         :param timeout: The timeout duration for Lambda function. Default: cdk.Duraction.seconds(180)
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CertbotProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4f0249540cbe176a86db839408b6a98feffc11711859731e9b41a932bc4ef767)
             check_type(argname="argument hosted_zone_names", value=hosted_zone_names, expected_type=type_hints["hosted_zone_names"])
             check_type(argname="argument letsencrypt_domains", value=letsencrypt_domains, expected_type=type_hints["letsencrypt_domains"])
             check_type(argname="argument letsencrypt_email", value=letsencrypt_email, expected_type=type_hints["letsencrypt_email"])
@@ -271,7 +271,7 @@ class CertbotProps:
             check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
             check_type(argname="argument sns_topic", value=sns_topic, expected_type=type_hints["sns_topic"])
             check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "hosted_zone_names": hosted_zone_names,
             "letsencrypt_domains": letsencrypt_domains,
             "letsencrypt_email": letsencrypt_email,
@@ -334,13 +334,13 @@ class CertbotProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+    def bucket(self) -> typing.Optional[_aws_cdk_aws_s3_55f001a5.Bucket]:
         '''The S3 bucket to place the resulting certificates in.
 
         If no bucket is given one will be created automatically.
         '''
         result = self._values.get("bucket")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_55f001a5.Bucket], result)
 
     @builtins.property
     def enable_insights(self) -> typing.Optional[builtins.bool]:
@@ -384,13 +384,15 @@ class CertbotProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def layers(self) -> typing.Optional[typing.List[aws_cdk.aws_lambda.ILayerVersion]]:
+    def layers(
+        self,
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_lambda_5443dbc3.ILayerVersion]]:
         '''Any additional Lambda layers to use with the created function.
 
         For example Lambda Extensions
         '''
         result = self._values.get("layers")
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_lambda.ILayerVersion]], result)
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_lambda_5443dbc3.ILayerVersion]], result)
 
     @builtins.property
     def object_prefix(self) -> typing.Optional[builtins.str]:
@@ -420,7 +422,7 @@ class CertbotProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+    def removal_policy(self) -> typing.Optional[_aws_cdk_core_f4b25747.RemovalPolicy]:
         '''The removal policy for the S3 bucket that is automatically created.
 
         Has no effect if a bucket is given as a property
@@ -428,7 +430,7 @@ class CertbotProps:
         :default: RemovalPolicy.RETAIN
         '''
         result = self._values.get("removal_policy")
-        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+        return typing.cast(typing.Optional[_aws_cdk_core_f4b25747.RemovalPolicy], result)
 
     @builtins.property
     def run_on_deploy(self) -> typing.Optional[builtins.bool]:
@@ -449,31 +451,31 @@ class CertbotProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def schedule(self) -> typing.Optional[aws_cdk.aws_events.Schedule]:
+    def schedule(self) -> typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule]:
         '''The schedule for the certificate check trigger.
 
         :default: events.Schedule.cron({ minute: '0', hour: '0', weekDay: '1' })
         '''
         result = self._values.get("schedule")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.Schedule], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule], result)
 
     @builtins.property
-    def sns_topic(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
+    def sns_topic(self) -> typing.Optional[_aws_cdk_aws_sns_889c7272.Topic]:
         '''The SNS topic to notify when a new cert is issued.
 
         If no topic is given one will be created automatically.
         '''
         result = self._values.get("sns_topic")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.Topic], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sns_889c7272.Topic], result)
 
     @builtins.property
-    def timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def timeout(self) -> typing.Optional[_aws_cdk_core_f4b25747.Duration]:
         '''The timeout duration for Lambda function.
 
         :default: cdk.Duraction.seconds(180)
         '''
         result = self._values.get("timeout")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[_aws_cdk_core_f4b25747.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -493,3 +495,55 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__0a97c57094adcc5a6d82e25accd2d32cc4403f75edfb6bdf2875a72fc23b1f8b(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    hosted_zone_names: typing.Sequence[builtins.str],
+    letsencrypt_domains: builtins.str,
+    letsencrypt_email: builtins.str,
+    bucket: typing.Optional[_aws_cdk_aws_s3_55f001a5.Bucket] = None,
+    enable_insights: typing.Optional[builtins.bool] = None,
+    enable_object_deletion: typing.Optional[builtins.bool] = None,
+    function_description: typing.Optional[builtins.str] = None,
+    function_name: typing.Optional[builtins.str] = None,
+    insights_arn: typing.Optional[builtins.str] = None,
+    layers: typing.Optional[typing.Sequence[_aws_cdk_aws_lambda_5443dbc3.ILayerVersion]] = None,
+    object_prefix: typing.Optional[builtins.str] = None,
+    preferred_chain: typing.Optional[builtins.str] = None,
+    re_issue_days: typing.Optional[jsii.Number] = None,
+    removal_policy: typing.Optional[_aws_cdk_core_f4b25747.RemovalPolicy] = None,
+    run_on_deploy: typing.Optional[builtins.bool] = None,
+    run_on_deploy_wait_minutes: typing.Optional[jsii.Number] = None,
+    schedule: typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule] = None,
+    sns_topic: typing.Optional[_aws_cdk_aws_sns_889c7272.Topic] = None,
+    timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4f0249540cbe176a86db839408b6a98feffc11711859731e9b41a932bc4ef767(
+    *,
+    hosted_zone_names: typing.Sequence[builtins.str],
+    letsencrypt_domains: builtins.str,
+    letsencrypt_email: builtins.str,
+    bucket: typing.Optional[_aws_cdk_aws_s3_55f001a5.Bucket] = None,
+    enable_insights: typing.Optional[builtins.bool] = None,
+    enable_object_deletion: typing.Optional[builtins.bool] = None,
+    function_description: typing.Optional[builtins.str] = None,
+    function_name: typing.Optional[builtins.str] = None,
+    insights_arn: typing.Optional[builtins.str] = None,
+    layers: typing.Optional[typing.Sequence[_aws_cdk_aws_lambda_5443dbc3.ILayerVersion]] = None,
+    object_prefix: typing.Optional[builtins.str] = None,
+    preferred_chain: typing.Optional[builtins.str] = None,
+    re_issue_days: typing.Optional[jsii.Number] = None,
+    removal_policy: typing.Optional[_aws_cdk_core_f4b25747.RemovalPolicy] = None,
+    run_on_deploy: typing.Optional[builtins.bool] = None,
+    run_on_deploy_wait_minutes: typing.Optional[jsii.Number] = None,
+    schedule: typing.Optional[_aws_cdk_aws_events_efcdfa54.Schedule] = None,
+    sns_topic: typing.Optional[_aws_cdk_aws_sns_889c7272.Topic] = None,
+    timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
